==> mule-maven-client-impl-2.3.9-20250724.011740-2-sources.jar: org/mule/maven/client/internal/DefaultPomFileSupplierFactory.java <==
/*
 * Copyright 2023 Salesforce, Inc. All rights reserved.
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.maven.client.internal;

import static org.mule.maven.client.internal.util.FileUtils.loadFileContentFrom;
import static org.mule.maven.pom.parser.internal.util.FileUtils.getPomUrlFromJar;

import static java.lang.String.format;

import static org.apache.commons.io.FileUtils.copyInputStreamToFile;

import org.mule.maven.client.api.PomFileSupplierFactory;
import org.mule.maven.pom.parser.api.model.BundleDescriptor;

import java.io.ByteArrayInputStream;
import java.io.File;
import java.io.IOException;
import java.net.URL;
import java.nio.file.Paths;
import java.util.Optional;
import java.util.function.Supplier;

public class DefaultPomFileSupplierFactory implements PomFileSupplierFactory {

  private static final char SEPARATOR = '~';

  /**
   * Pom file supplier that retrieves the pom file location from an artifact folder.
   * <p>
   * It is expected that the artifact folows the maven convention for the location of the pom file.
   *
   * @param artifactFolder           the folder with the uncompressed maven artifact.
   * @param artifactBundleDescriptor the descriptor of the maven artifact.
   * @return a supplier that retrieves the pom file location from an artifact folder.
   */
  public Supplier<File> uncompressPomArtifactSupplier(File artifactFolder, BundleDescriptor artifactBundleDescriptor) {
    return () -> {
      String pathToPom = Paths
          .get("META-INF", "maven", artifactBundleDescriptor.getGroupId(), artifactBundleDescriptor.getArtifactId(), "pom.xml")
          .toString();
      return new File(artifactFolder, pathToPom);
    };
  }


  /**
   * Pom file supplier that retrieves the pom file location from a compressed artifact.
   * <p>
   * It will use a temporary folder to be able to create a {@link File} object to point to.
   *
   * @param artifactFile             the compressed artifact file.
   * @param artifactBundleDescriptor the bundle descriptor.
   * @param temporaryFolder          the temporary folder to use to create the pom file.
   * @return a supplier that retrieves the pom file location from the compressed artifact.
   */
  public Supplier<File> compressedArtifactSupplier(File artifactFile, BundleDescriptor artifactBundleDescriptor,
                                                   File temporaryFolder) {
    return () -> {
      try {
        URL pomUrl = getPomUrlFromJar(artifactFile);
        Optional<byte[]> pomContentOptional = loadFileContentFrom(pomUrl);
        byte[] pomBytes =
            pomContentOptional.orElseThrow(() -> new RuntimeException(format("No pom file found in %s", artifactFile)));

        StringBuilder path = new StringBuilder(128);
        path.append(artifactBundleDescriptor.getGroupId()).append(SEPARATOR);
        path.append(artifactBundleDescriptor.getArtifactId()).append(SEPARATOR);
        path.append(artifactBundleDescriptor.getBaseVersion() != null ? artifactBundleDescriptor.getBaseVersion()
            : artifactBundleDescriptor.getVersion());
        path.append(".pom");

        File pomLocation = new File(temporaryFolder, path.toString());
        copyInputStreamToFile(new ByteArrayInputStream(pomBytes), pomLocation);
        return pomLocation;
      } catch (IOException e) {
        throw new RuntimeException(e);
      }
    };
  }



}

==> mule-maven-client-impl-2.6.0-20251114.215256-12-sources.jar: org/mule/maven/client/internal/DefaultPomFileSupplierFactory.java <==
/*
 * Copyright 2023 Salesforce, Inc. All rights reserved.
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.maven.client.internal;

import static org.mule.maven.client.internal.util.FileUtils.loadFileContentFrom;
import static org.mule.maven.pom.parser.internal.util.FileUtils.getPomUrlFromJar;

import static java.lang.String.format;
import static java.nio.file.Files.createDirectories;
import static java.nio.file.Files.write;

import org.mule.maven.client.api.PomFileSupplierFactory;
import org.mule.maven.pom.parser.api.model.BundleDescriptor;

import java.io.File;
import java.io.IOException;
import java.net.URL;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.util.Optional;
import java.util.function.Supplier;

public class DefaultPomFileSupplierFactory implements PomFileSupplierFactory {

  private static final char SEPARATOR = '~';

  /**
   * Pom file supplier that retrieves the pom file location from an artifact folder.
   * <p>
   * It is expected that the artifact folows the maven convention for the location of the pom file.
   *
   * @param artifactFolder           the folder with the uncompressed maven artifact.
   * @param artifactBundleDescriptor the descriptor of the maven artifact.
   * @return a supplier that retrieves the pom file location from an artifact folder.
   */
  @Override
  public Supplier<File> uncompressPomArtifactSupplier(File artifactFolder, BundleDescriptor artifactBundleDescriptor) {
    return () -> uncompressPomArtifactSupplier(artifactFolder.toPath(), artifactBundleDescriptor).get().toFile();
  }

  /**
   * Pom file supplier that retrieves the pom file location from a compressed artifact.
   * <p>
   * It will use a temporary folder to be able to create a {@link File} object to point to.
   *
   * @param artifactFile             the compressed artifact file.
   * @param artifactBundleDescriptor the bundle descriptor.
   * @param temporaryFolder          the temporary folder to use to create the pom file.
   * @return a supplier that retrieves the pom file location from the compressed artifact.
   */
  @Override
  public Supplier<File> compressedArtifactSupplier(File artifactFile, BundleDescriptor artifactBundleDescriptor,
                                                   File temporaryFolder) {
    return () -> compressedArtifactSupplier(artifactFile.toPath(), artifactBundleDescriptor, temporaryFolder.toPath()).get()
        .toFile();
  }

  /**
   * Pom file supplier that retrieves the pom file location from an artifact folder.
   * <p>
   * It is expected that the artifact folows the maven convention for the location of the pom file.
   *
   * @param artifactFolder           the folder with the uncompressed maven artifact.
   * @param artifactBundleDescriptor the descriptor of the maven artifact.
   * @return a supplier that retrieves the pom file location from an artifact folder.
   */
  @Override
  public Supplier<Path> uncompressPomArtifactSupplier(Path artifactFolder, BundleDescriptor artifactBundleDescriptor) {
    return () -> {
      String pathToPom = Paths
          .get("META-INF", "maven", artifactBundleDescriptor.getGroupId(), artifactBundleDescriptor.getArtifactId(), "pom.xml")
          .toString();
      return artifactFolder.resolve(pathToPom);
    };
  }


  /**
   * Pom file supplier that retrieves the pom file location from a compressed artifact.
   * <p>
   * It will use a temporary folder to be able to create a {@link File} object to point to.
   *
   * @param artifactFile             the compressed artifact file.
   * @param artifactBundleDescriptor the bundle descriptor.
   * @param temporaryFolder          the temporary folder to use to create the pom file.
   * @return a supplier that retrieves the pom file location from the compressed artifact.
   */
  @Override
  public Supplier<Path> compressedArtifactSupplier(Path artifactFile, BundleDescriptor artifactBundleDescriptor,
                                                   Path temporaryFolder) {
    return () -> {
      try {
        URL pomUrl = getPomUrlFromJar(artifactFile);
        Optional<byte[]> pomContentOptional = loadFileContentFrom(pomUrl);
        byte[] pomBytes =
            pomContentOptional.orElseThrow(() -> new RuntimeException(format("No pom file found in %s", artifactFile)));

        StringBuilder path = new StringBuilder(128);
        path.append(artifactBundleDescriptor.getGroupId()).append(SEPARATOR);
        path.append(artifactBundleDescriptor.getArtifactId()).append(SEPARATOR);
        path.append(artifactBundleDescriptor.getBaseVersion() != null ? artifactBundleDescriptor.getBaseVersion()
            : artifactBundleDescriptor.getVersion());
        path.append(".pom");

        Path pomLocation = temporaryFolder.resolve(path.toString());
        createDirectories(temporaryFolder);
        write(pomLocation, pomBytes);
        return pomLocation;
      } catch (IOException e) {
        throw new RuntimeException(e);
      }
    };
  }



}
